{ config, pkgs, ... }:
{
  imports =
    [
      ./hardware-configuration.nix
      ../../modules/tuxedo-rs.nix
      ../../modules/gpu-amd.nix

      # LAN issues
      #
      # Chose one of these two:
      #./old-kernel-with-working-lan.nix
      ./latest-kernel.nix

      # Wi-Fi 6 AX200 issues
      #
      # - If the device hangs up with the Wi-Fi module being used, it might be stuck in an "error state" even after reboot and can't be used under Linux
      # - One solution involves booting Windows which then "resets" the Wi-Fi module. https://bbs.archlinux.org/viewtopic.php?id=296091
      # - However, another one is more straight forward (https://www.reddit.com/r/archlinux/comments/kuy8fq/comment/giv7nq1/):
      #   - `nix-shell -p pciutils --run 'lspci -k' | grep Network`
      #   - Take note of your PCI device number, e.g. `01:00.0`
      #   - Let the device reset itself (as root): `echo 1 > /sys/bus/pci/devices/0000:01:00.0/reset`
      #   - `reboot`
      # - Related: https://unix.stackexchange.com/a/667997

      ../../modules/home-manager.nix
      ../../modules/nur-and-unstable.nix
      ../../modules/unfree.nix
      ../../modules/base.nix
      ../../modules/base-efi-systemd.nix
      ../../modules/xdg.nix
      ../../modules/power-management.nix
      ../../modules/usb-mtp-ptp.nix
      ../../modules/ntfs.nix
      ../../modules/git.nix
      ../../modules/nitrokey-gpg-smartcard.nix
      ../../modules/ssh-client.nix
      ../../modules/ssh-server.nix
      ../../modules/lid-switch-handling.nix
      #../../modules/package-list.nix

      ../../modules/btrfs-scrub.nix
      ../../modules/btrfs-mount-options.nix

      #../../modules/headless.nix
      #
      #../../modules/kde.nix
      #../../modules/programs-kde.nix
      #
      ../../modules/gnome-base.nix
      ../../modules/gnome-fractional-scaling.nix
      #../../modules/fwupd-gnome.nix # TODO: Constantly keeps installing the same fw update again
      ../../modules/programs-gnome.nix

      ../../modules/programs-base.nix
      ../../modules/programs.nix
      ../../modules/flatpak.nix
      ../../modules/rnote.nix
      ../../modules/ausweisapp.nix
      ../../modules/nextcloud-client.nix
      ../../modules/syncthing.nix
      ../../modules/signal-desktop.nix
      ../../modules/element-desktop.nix
      ../../modules/obsidian.nix
      ../../modules/vlc-dvd-blu-ray.nix
      ../../modules/firefox.nix
      ../../modules/tor-browser.nix
      #../../modules/tor.nix
      ../../modules/digikam-rawtherapee-hugin-gimp.nix
      ../../modules/freetube.nix
      ../../modules/print-and-scan.nix
      #../../modules/waydroid.nix
      ../../modules/uni-vpn.nix
      #../../modules/epa.nix

      ../../modules/games.nix
      #../../modules/dosbox-x.nix
      ../../modules/steam.nix

      #../../modules/autostart.nix

      ../../modules/jetbrains-ide.nix
      #../../modules/vscodium.nix
      ../../modules/android.nix
      #../../modules/pmbootstrap.nix

      #../../modules/boxes.nix
      #../../modules/virtualbox.nix
      #../../modules/virt-manager.nix
      ../../modules/docker.nix
      ../../modules/docker-pushrm.nix
    ];

  networking.hostName = "yodaTux";
  boot.initrd.luks.devices."luks-ea7099e3-320d-4eb3-a4c3-9910a9af817b".allowDiscards = true;
  yoda.btrfsFileSystems = ["/"];
  #yoda.btrfsMounts = yoda.btrfsFileSystems;

  # Systemd Journal entry:
  # S Sat Sep 23 16:11:52 2023 p4 kernel: TSC found unstable after boot, most likely due to broken BIOS. Use 'tsc=unstable'.
  boot.kernelParams = [ "tsc=unstable" ];

  # Most users should never change this value after the initial install, for any reason, even if you've upgraded your system to a new NixOS release.
  system.stateVersion = "23.05";
}
